@@ -16,4 +16,4 @@
 #' @docType package
 #' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
 #' @keywords package
-NULL
+"_PACKAGE"
